@@ -513,13 +513,16 @@ class KafkaApp:
 
     async def run(self):
         self.logger.info('{} is up and running.'.format(self.app_name))
-        await asyncio.gather(*[
-            self.listener.listen(),
-            self.process_sync_tasks(),
-            self.process_async_tasks(),
-            self.process_pipelines(),
-            self.process_caching()
-        ])
+        try:
+            await asyncio.gather(*[
+                self.listener.listen(),
+                self.process_sync_tasks(),
+                self.process_async_tasks(),
+                self.process_pipelines(),
+                self.process_caching()
+            ])
+        except KeyboardInterrupt:
+            self.close()
 
     def close(self):
         self.listener.stop = True
